@@ -55,7 +55,7 @@
 #'                          latitude = rnorm(n_obs, sd = 0.1),
 #'                          day_of_year = sample.int(28, n_obs, replace = TRUE),
 #'                          year = NA_integer_,
-#'                          obs = rpois(n_obs, lambda = 0.1),
+#'                          obs = rpois(n_obs, lambda = 0.05),
 #'                          forest_cover = runif(n_obs),
 #'                          island = as.integer(runif(n_obs) > 0.95))
 #' # add a year column, giving more data to recent years
@@ -171,10 +171,12 @@ grid_sample <- function(x,
 #' @param unified_grid logical; whether a single, unified spatiotemporal
 #'   sampling grid should be defined and used for all observations in `x` or a
 #'   different grid should be used for each stratum.
-#' @param by_year logical; whether the sampling should be done by year, i.e.
-#'   sampling N observations per grid cell per year, rather than across years,
-#'   i.e. N observations per grid cell regardless of year. If using sampling by
-#'   year, the input data frame `x` must have a `year` column.
+#' @param by_year logical; whether the sampling should be done stratified by
+#'   year (TRUE) or ignoring year (FALSE). If sampling by year is turned on, N
+#'   observations will be sampled from each grid cell for each year, while if it
+#'   is turned off, N observations will be sampled per grid cell across all
+#'   years. If using sampling by year, the input data frame `x` must have a
+#'   `year` column.
 #' @param case_control logical; whether to apply case control sampling whereby
 #'   presence and absence are sampled independently.
 #' @param obs_column character; if `case_control = TRUE`, this is the name of
@@ -555,11 +557,7 @@ assign_to_grid <- function(points,
   # project to equal area if unprojected
   if (is_lonlat) {
     stopifnot(all(c("longitude", "latitude") %in% names(points)))
-    coords <- terra::vect(points[, c("longitude", "latitude")],
-                          geom = c("longitude", "latitude"),
-                          crs = "epsg:4326")
-    coords <- terra::project(coords, y = "+proj=eck4")
-    coords <- as.data.frame(terra::crds(coords))
+    coords <- project_equal_area(points, c("longitude", "latitude"))
     # add temporal columns
     if ("t" %in% names(points)) {
       coords[["t"]] <- points[["t"]]
@@ -633,7 +631,8 @@ assign_to_grid <- function(points,
 # project to equal area
 project_equal_area <- function(points, coords = c("longitude", "latitude")) {
   stopifnot(all(coords %in% names(points)))
-  locs <- terra::vect(points[, coords], geom = coords, crs = "epsg:4326")
+  locs <- terra::vect(as.data.frame(points[, coords]),
+                      geom = coords, crs = "epsg:4326")
   locs <- terra::project(locs, y = "+proj=eck4")
   locs <- as.data.frame(terra::crds(locs))
   return(stats::setNames(locs, c("x", "y")))
